# generators
Ontology Based System Engineering


## Installation

```bash
pip install artifact-generator
```

## Installation for development purposes
```
pip install -e .   
```

## Usage

```
gen --help
```


## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## Authors and acknowledgment

- For readme file I used format from https://www.makeareadme.com/

## License
[GNU GPLv3](https://choosealicense.com/licenses/gpl-3.0/)
